@@ -29,10 +29,10 @@ class TestMyfcidApiBackend(TestCase):
 
         # Checar se o usuário foi autenticado corretamente
         self.assertNotEqual(identity, None)
-        self.assertEquals(identity.first_name, 'Identity')
-        self.assertEquals(identity.last_name, 'Client')
-        self.assertEquals(identity.email, test_user_email)
-        self.assertEquals(identity.user_data, {
+        self.assertEqual(identity.first_name, 'Identity')
+        self.assertEqual(identity.last_name, 'Client')
+        self.assertEqual(identity.email, test_user_email)
+        self.assertEqual(identity.user_data, {
             u'authentication_key': u'$2a$12$nA3ad2y5aSBlg80K9ekbNuvnRO1OI1WUKZyoJqWEhk.PQpD8.6jkS',
             u'email': u'identity_client@disposableinbox.com',
             u'first_name': u'Identity',
@@ -48,7 +48,7 @@ class TestMyfcidApiBackend(TestCase):
         })
 
         # Checar se o backend foi setado corretamente
-        self.assertEquals(
+        self.assertEqual(
             identity.backend,
             '%s.%s' % (MyfcidAPIBackend.__module__, 'MyfcidAPIBackend')
         )
@@ -60,7 +60,7 @@ class TestMyfcidApiBackend(TestCase):
             identity = MyfcidAPIBackend().authenticate(test_user_email, 'senha errada')
 
         # Garantir que o usuario não foi autenticado
-        self.assertEquals(identity, None)
+        self.assertEqual(identity, None)
 
 
     def test_auth_updates_user(self):
@@ -72,16 +72,16 @@ class TestMyfcidApiBackend(TestCase):
             identity = MyfcidAPIBackend().authenticate(test_user_email, test_user_password)
 
         # Checar se os dados do usuário foram atualizados
-        self.assertEquals(identity.first_name, 'Identity')
-        self.assertEquals(identity.last_name, 'Client') 
-        self.assertEquals(identity.email, test_user_email)
-        self.assertEquals(identity.uuid, test_user_uuid)
+        self.assertEqual(identity.first_name, 'Identity')
+        self.assertEqual(identity.last_name, 'Client')
+        self.assertEqual(identity.email, test_user_email)
+        self.assertEqual(identity.uuid, test_user_uuid)
 
 
     @patch.object(settings, 'SERVICE_ACCOUNT_MODULE', 'identity_client.ServiceAccount')
     def test_create_local_identity_creates_user_accounts(self):
         # Obter dados do usuário
-        with identity_client.tests.use_cassette('fetch_identity_data/success_with_accounts'):
+        with identity_client.tests.use_cassette('fetch_identity_data/success'):
             response = APIClient.fetch_identity_data(uuid=test_user_uuid)
             status_code, content, error = response
 
@@ -91,7 +91,7 @@ class TestMyfcidApiBackend(TestCase):
         # 1 conta deve ter sido criada
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 3)
+        self.assertEqual(accounts.count(), 5)
 
 
     @patch.object(settings, 'SERVICE_ACCOUNT_MODULE', 'identity_client.ServiceAccount')
@@ -107,10 +107,10 @@ class TestMyfcidApiBackend(TestCase):
         # 5 contas devem ter sido criadas
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 5)
+        self.assertEqual(accounts.count(), 5)
 
         # Obter os dados do usuário, desta vez sem accounts
-        with identity_client.tests.use_cassette('fetch_identity_data/success_with_accounts'):
+        with identity_client.tests.use_cassette('fetch_identity_data/success'):
             response = APIClient.fetch_identity_data(uuid=test_user_uuid)
             status_code, content, error = response
 
@@ -120,12 +120,12 @@ class TestMyfcidApiBackend(TestCase):
         # O usuário deve ter sido dissociado da account
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 3)
+        self.assertEqual(accounts.count(), 5)
 
 
     def test_accounts_creation_fails_if_settings_are_wrong(self):
         # Obter dados do usuário
-        with identity_client.tests.use_cassette('fetch_identity_data/success_with_accounts'):
+        with identity_client.tests.use_cassette('fetch_identity_data/success'):
             response = APIClient.fetch_identity_data(uuid=test_user_uuid)
             status_code, content, error = response
 
@@ -138,12 +138,12 @@ class TestMyfcidApiBackend(TestCase):
         # Nenhuma conta foi criada
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 0)
+        self.assertEqual(accounts.count(), 0)
 
 
     def test_auth_user_accounts_creation_fails_if_settings_are_missing(self):
         # Obter dados do usuário
-        with identity_client.tests.use_cassette('fetch_identity_data/success_with_accounts'):
+        with identity_client.tests.use_cassette('fetch_identity_data/success'):
             response = APIClient.fetch_identity_data(uuid=test_user_uuid)
             status_code, content, error = response
 
@@ -156,13 +156,13 @@ class TestMyfcidApiBackend(TestCase):
         # Nenhuma conta foi criada
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 0)
+        self.assertEqual(accounts.count(), 0)
 
 
     @patch.object(settings, 'SERVICE_ACCOUNT_MODULE', 'identity_client.ServiceAccount')
     def test_authentication_should_not_remove_user_accounts(self):
         # Obter dados do usuário
-        with identity_client.tests.use_cassette('fetch_identity_data/success_with_accounts'):
+        with identity_client.tests.use_cassette('fetch_identity_data/success'):
             response = APIClient.fetch_identity_data(uuid=test_user_uuid)
             status_code, content, error = response
 
@@ -172,7 +172,7 @@ class TestMyfcidApiBackend(TestCase):
         # 1 conta deve ter sido criada
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 3)
+        self.assertEqual(accounts.count(), 5)
 
         # Autenticar o usuário
         with identity_client.tests.use_cassette('myfcid_api_backend/success'):
@@ -181,7 +181,7 @@ class TestMyfcidApiBackend(TestCase):
         # A conta deve continuar existindo
         serviceAccountModel = get_account_module()
         accounts = serviceAccountModel.for_identity(identity)
-        self.assertEquals(accounts.count(), 3)
+        self.assertEqual(accounts.count(), 5)
 
 
 class TestGetUser(TestCase):
@@ -195,7 +195,7 @@ class TestGetUser(TestCase):
     def test_valid_user(self):
         identity = self._create_user()
         user = get_user(userid=identity.id)
-        self.assertEquals(user, identity)
+        self.assertEqual(user, identity)
 
 
     def test_user_not_sent(self):
@@ -214,7 +214,7 @@ class TestFetchUserData(TestCase):
         with identity_client.tests.use_cassette('myfcid_api_backend/success'):
             _, user_data, _ = MyfcidAPIBackend().fetch_user_data(test_user_email, test_user_password)
 
-        self.assertEquals(user_data, {
+        self.assertEqual(user_data, {
             u'authentication_key': u'$2a$12$nA3ad2y5aSBlg80K9ekbNuvnRO1OI1WUKZyoJqWEhk.PQpD8.6jkS',
             u'email': u'identity_client@disposableinbox.com',
             u'first_name': u'Identity',
@@ -233,5 +233,8 @@ class TestFetchUserData(TestCase):
         with identity_client.tests.use_cassette('myfcid_api_backend/wrong_password'):
             _, user_data, error = MyfcidAPIBackend().fetch_user_data(test_user_email, 'senha errada')
 
-        self.assertEquals(user_data, None)
-        self.assertEquals(error, {'status': 401, 'message': '401 Client Error: UNAUTHORIZED'})
+        self.assertEqual(user_data, None)
+        self.assertEqual(
+            error,
+            {'status': 401, 'message': u'{"detail": "You need to login or otherwise authenticate the request."}'}
+        )
